from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.anchor import image_template

items = ImageItems(
    {
        image_template.format("03.png"): "",
        image_template.format("20251205_175953.jpg"): "",
    }
)



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.cheshmak import image_template

items = ImageItems(
    {
        image_template.format("01.png"): "",
        image_template.format("20251203_190023.jpg"): "",
    }
)



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.swallow.consts import swallow_assets2
from bluer_sbc.README.designs.swallow import image_template, latest_version

docs = (
    [
        {
            "path": "../docs/swallow/body",
            "items": ImageItems(
                {
                    image_template(latest_version).format(f"{index+1:02}.jpg"): ""
                    for index in range(6)
                }
            ),
        }
    ]
    + [
        {
            "path": "../docs/swallow/body/v1.md",
            "items": ImageItems(
                {
                    f"{swallow_assets2}/20250609_164433.jpg": "",
                    f"{swallow_assets2}/20250614_114954.jpg": "",
                    f"{swallow_assets2}/20250615_192339.jpg": "",
                }
            ),
        }
    ]
    + [
        {
            "path": f"../docs/swallow/body/v{version}.md",
            "items": ImageItems(
                {
                    image_template(version).format(
                        f"{index+1:02}.jpg",
                    ): ""
                    for index in range(6)
                }
            ),
        }
        for version in range(2, latest_version)
    ]
)



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.cheshmak import image_template
from bluer_sbc.README.designs.cheshmak.body import v1

docs = [
    {
        "path": "../docs/cheshmak/body",
        "items": ImageItems(
            {
                image_template.format("20251203_184658.jpg"): "",
                image_template.format("20251203_184702.jpg"): "",
                image_template.format("20251203_184706.jpg"): "",
                image_template.format("20251203_184712.jpg"): "",
                image_template.format("20251203_184717.jpg"): "",
                image_template.format("20251203_184723.jpg"): "",
                image_template.format("20251203_190023.jpg"): "",
                image_template.format("20251203_190131.jpg"): "",
                image_template.format("20251203_190344.jpg"): "",
            }
        ),
    }
] + v1.docs



from bluer_sbc.README.design import design_doc_parts

parts = {
    "plexiglass": "2 x 90 mm x 90 mm",
    "rpi": "",
    "rpi-camera": "",
    "nuts-bolts-spacers": "M2.5: ({})".format(
        " + ".join(
            [
                "4 x bolt",
                "4 x nut",
                "12 x 10 mm spacer",
                "4 x 15 mm spacer",
            ]
        )
    ),
}


docs = [
    {
        "path": "../docs/cheshmak/parts.md",
        "macros": design_doc_parts(
            dict_of_parts=parts,
            parts_reference="../parts",
        ),
    }
]



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.battery_bus import image_template

docs = [
    {
        "path": "../docs/battery_bus/body/sla.md",
        "items": ImageItems(
            {
                image_template.format("20251007_221902.jpg"): "",
                image_template.format("20251007_220642.jpg"): "",
                image_template.format("20251007_220520.jpg"): "",
                image_template.format("20251007_220601.jpg"): "",
            }
        ),
    }
]



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.anchor import image_template

docs = [
    {
        "path": "../docs/anchor/body/v2.md",
        "items": ImageItems(
            {
                image_template.format("20251205_175910.jpg"): "",
                image_template.format("20251205_175916.jpg"): "",
                image_template.format("20251205_175920.jpg"): "",
                image_template.format("20251205_175932.jpg"): "",
                image_template.format("20251205_175936.jpg"): "",
                image_template.format("20251205_175941.jpg"): "",
                image_template.format("20251205_175953.jpg"): "",
            }
        ),
    },
]
